==> tamejs-0.1.5.tgz: package/test/cases/9.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    
    var res = 0 ;
    function foo (cb) {
        var __tame_this = this;
        var __tame_fn_1 = function (__tame_k) {
            var __tame_fn_2 = function (__tame_k) {
                var __tame_ev = new tame.Event (__tame_k);
                var __tame_fn_3 = function (__tame_k) {
                    setTimeout ( __tame_ev.mkevent ( ) , 10 * Math .random ( ) ) ;
                    tame.callChain([__tame_k]);
                };
                __tame_fn_3(tame.end);
                __tame_ev.trigger();
            };
            var __tame_fn_4 = function (__tame_k) {
                res ++ ;
                cb ( ) ;
                tame.callChain([__tame_k]);
            };
            tame.callChain([__tame_fn_2, __tame_fn_4, __tame_k]);
        };
        tame.callChain([__tame_fn_1, __tame_k]);
    }
    ;
    
    exports [ "parser variations" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_5 = function (__tame_k) {
            var __tame_fn_6 = function (__tame_k) {
                var __tame_fn_7 = function (__tame_k) {
                    var __tame_ev = new tame.Event (__tame_k);
                    var __tame_fn_8 = function (__tame_k) {
                        foo ( __tame_ev.mkevent ( ) ) ;
                        tame.callChain([__tame_k]);
                    };
                    __tame_fn_8(tame.end);
                    __tame_ev.trigger();
                };
                if (true) {
                    tame.callChain([__tame_fn_7, __tame_k]);
                } else {
                    tame.callChain([__tame_k]);
                }
            };
            var __tame_fn_9 = function (__tame_k) {
                res ++ ;
                cb ( ) ;
                tame.callChain([__tame_k]);
            };
            tame.callChain([__tame_fn_6, __tame_fn_9, __tame_k]);
        };
        tame.callChain([__tame_fn_5, __tame_k]);
    }
    ,
    check :
    function  () {
        assert .equal ( res , 2 , "both increments fired" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);

==> tamejs-0.2.1.tgz: package/test/cases/9.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    var assert = require ( "assert" ) ;
    
    var res = 0 ;
    function foo (cb) {
        var __tame_this = this;
        var __tame_fn_1 = function (__tame_k) {
            var __tame_fn_2 = function (__tame_k) {
                var __tame_ev = new tame.Event (__tame_k);
                var __tame_fn_3 = function (__tame_k) {
                    setTimeout (
                    __tame_ev.mkevent ()
                    , 10 * Math .random ( ) ) ;
                    tame.callChain([__tame_k]);
                };
                __tame_fn_3(tame.end);
                __tame_ev.trigger();
            };
            var __tame_fn_4 = function (__tame_k) {
                res ++ ;
                cb ( ) ;
                tame.callChain([__tame_k]);
            };
            tame.callChain([__tame_fn_2, __tame_fn_4, __tame_k]);
        };
        tame.callChain([__tame_fn_1, __tame_k]);
    }
    ;
    
    exports [ "parser variations" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_5 = function (__tame_k) {
            var __tame_fn_6 = function (__tame_k) {
                var __tame_fn_7 = function (__tame_k) {
                    var __tame_ev = new tame.Event (__tame_k);
                    var __tame_fn_8 = function (__tame_k) {
                        foo (
                        __tame_ev.mkevent ()
                        ) ;
                        tame.callChain([__tame_k]);
                    };
                    __tame_fn_8(tame.end);
                    __tame_ev.trigger();
                };
                if (true) {
                    tame.callChain([__tame_fn_7, __tame_k]);
                } else {
                    tame.callChain([__tame_k]);
                }
            };
            var __tame_fn_9 = function (__tame_k) {
                res ++ ;
                cb ( ) ;
                tame.callChain([__tame_k]);
            };
            tame.callChain([__tame_fn_6, __tame_fn_9, __tame_k]);
        };
        tame.callChain([__tame_fn_5, __tame_k]);
    }
    ,
    check :
    function  () {
        assert .equal ( res , 2 , "both increments fired" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);
